@@ -2,6 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2006 Stefan Walter
+ * Copyright (C) 2011 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,7 +55,6 @@ enum {
     PROP_ITEM_ID,
     PROP_ITEM_INFO,
     PROP_ITEM_ATTRIBUTES,
-    PROP_ITEM_ACL,
     PROP_HAS_SECRET,
     PROP_USE
 };
@@ -68,10 +68,6 @@ struct _SeahorseGkrItemPrivate {
 	
 	gpointer req_attrs;
 	GnomeKeyringAttributeList *item_attrs;
-	
-	gpointer req_acl;
-	gboolean got_acl;
-	GList *item_acl;
 
 	gpointer req_secret;
 	gchar *item_secret;
@@ -83,7 +79,7 @@ G_DEFINE_TYPE (SeahorseGkrItem, seahorse_gkr_item, SEAHORSE_TYPE_OBJECT);
  * INTERNAL HELPERS
  */
 
-GType
+static GType
 boxed_item_info_type (void)
 {
 	static GType type = 0;
@@ -94,7 +90,7 @@ boxed_item_info_type (void)
 	return type;
 }
 
-GType
+static GType
 boxed_attributes_type (void)
 {
 	static GType type = 0;
@@ -105,17 +101,6 @@ boxed_attributes_type (void)
 	return type;
 }
 
-GType
-boxed_acl_type (void)
-{
-	static GType type = 0;
-	if (!type)
-		type = g_boxed_type_register_static ("GnomeKeyringAcl", 
-		                                     (GBoxedCopyFunc)gnome_keyring_acl_copy,
-		                                     (GBoxedFreeFunc)gnome_keyring_acl_free);
-	return type;
-}
-
 static gboolean 
 received_result (SeahorseGkrItem *self, GnomeKeyringResult result)
 {
@@ -227,38 +212,6 @@ require_item_attrs (SeahorseGkrItem *self)
 	return self->pv->item_attrs != NULL;
 }
 
-static void
-received_item_acl (GnomeKeyringResult result, GList *acl, gpointer data)
-{
-	SeahorseGkrItem *self = SEAHORSE_GKR_ITEM (data);
-	self->pv->req_acl = NULL;
-	if (received_result (self, result)) {
-		self->pv->got_acl = TRUE;
-		seahorse_gkr_item_set_acl (self, acl);
-	}
-}
-
-static void
-load_item_acl (SeahorseGkrItem *self)
-{
-	/* Already in progress */
-	if (!self->pv->req_acl) {
-		g_object_ref (self);
-		self->pv->req_acl = gnome_keyring_item_get_acl (self->pv->keyring_name,
-		                                                self->pv->item_id,
-		                                                received_item_acl,
-		                                                self, g_object_unref);
-	}
-}
-
-static gboolean
-require_item_acl (SeahorseGkrItem *self)
-{
-	if (!self->pv->got_acl)
-		load_item_acl (self);
-	return self->pv->got_acl;
-}
-
 static guint32
 find_attribute_int (GnomeKeyringAttributeList *attrs, const gchar *name)
 {
@@ -459,23 +412,14 @@ calc_item_type (SeahorseGkrItem *self)
  * OBJECT 
  */
 
-static void
-seahorse_gkr_item_realize (SeahorseObject *obj)
+void
+seahorse_gkr_item_realize (SeahorseGkrItem *self)
 {
-	SeahorseGkrItem *self = SEAHORSE_GKR_ITEM (obj);
-	const gchar *description;
 	gchar *display;
 	gchar *markup;
 	gchar *identifier;
 	const gchar *icon;
 
-	if (is_network_item (self, "http")) 
-		description = _("Web Password");
-	else if (is_network_item (self, NULL)) 
-		description = _("Network Password");
-	else
-		description = _("Password");
-
 	display = calc_display_name (self, TRUE);
 	markup = calc_name_markup(self);
 	identifier = g_strdup_printf ("%u", self->pv->item_id);
@@ -502,8 +446,7 @@ seahorse_gkr_item_realize (SeahorseObject *obj)
 		      "icon", icon,
 		      "markup", markup,
 		      "identifier", identifier,
-		      "description", description,
-		      "flags", 0,
+		      "flags", SEAHORSE_FLAG_DELETABLE,
 		      NULL);
 	
 	g_free (display);
@@ -512,32 +455,17 @@ seahorse_gkr_item_realize (SeahorseObject *obj)
 	
 	g_object_notify (G_OBJECT (self), "has-secret");
 	g_object_notify (G_OBJECT (self), "use");
-	
-	SEAHORSE_OBJECT_CLASS (seahorse_gkr_item_parent_class)->realize (obj);
 }
 
-static void
-seahorse_gkr_item_refresh (SeahorseObject *obj)
+void
+seahorse_gkr_item_refresh (SeahorseGkrItem *self)
 {
-	SeahorseGkrItem *self = SEAHORSE_GKR_ITEM (obj);
-	
 	if (self->pv->item_info)
 		load_item_info (self);
 	if (self->pv->item_attrs)
 		load_item_attrs (self);
-	if (self->pv->got_acl)
-		load_item_acl (self);
 	if (self->pv->item_secret)
 		load_item_secret (self);
-
-	SEAHORSE_OBJECT_CLASS (seahorse_gkr_item_parent_class)->refresh (obj);
-}
-
-static SeahorseOperation*
-seahorse_gkr_item_delete (SeahorseObject *obj)
-{
-	SeahorseGkrItem *self = SEAHORSE_GKR_ITEM (obj);
-	return seahorse_gkr_operation_delete_item (self);
 }
 
 static void
@@ -547,23 +475,20 @@ seahorse_gkr_item_init (SeahorseGkrItem *self)
 	g_object_set (self, "usage", SEAHORSE_USAGE_CREDENTIALS, "tag", SEAHORSE_GKR_TYPE, "location", SEAHORSE_LOCATION_LOCAL, NULL);
 }
 
-static GObject* 
-seahorse_gkr_item_constructor (GType type, guint n_props, GObjectConstructParam *props) 
+static void
+seahorse_gkr_item_constructed (GObject *object)
 {
-	GObject *obj = G_OBJECT_CLASS (seahorse_gkr_item_parent_class)->constructor (type, n_props, props);
-	SeahorseGkrItem *self = NULL;
+	SeahorseGkrItem *self = SEAHORSE_GKR_ITEM (object);
 	GQuark id;
-	
-	if (obj) {
-		self = SEAHORSE_GKR_ITEM (obj);
-		
-		id = seahorse_gkr_item_get_cannonical (self->pv->keyring_name, 
-		                                        self->pv->item_id);
-		g_object_set (self, "id", id, 
-		              "usage", SEAHORSE_USAGE_CREDENTIALS, NULL); 
-	}
-	
-	return obj;
+
+	G_OBJECT_CLASS (seahorse_gkr_item_parent_class)->constructed (object);
+
+	id = seahorse_gkr_item_get_cannonical (self->pv->keyring_name,
+	                                       self->pv->item_id);
+	g_object_set (self, "id", id,
+	              "usage", SEAHORSE_USAGE_CREDENTIALS, NULL);
+
+	seahorse_gkr_item_realize (self);
 }
 
 static void
@@ -585,9 +510,6 @@ seahorse_gkr_item_get_property (GObject *object, guint prop_id,
 	case PROP_ITEM_ATTRIBUTES:
 		g_value_set_boxed (value, seahorse_gkr_item_get_attributes (self));
 		break;
-	case PROP_ITEM_ACL:
-		g_value_set_boxed (value, seahorse_gkr_item_get_acl (self));
-		break;
 	case PROP_HAS_SECRET:
 		g_value_set_boolean (value, self->pv->item_secret != NULL);
 		break;
@@ -621,9 +543,6 @@ seahorse_gkr_item_set_property (GObject *object, guint prop_id, const GValue *va
 	case PROP_ITEM_ATTRIBUTES:
 		seahorse_gkr_item_set_attributes (self, g_value_get_boxed (value));
 		break;
-	case PROP_ITEM_ACL:
-		seahorse_gkr_item_set_acl (self, g_value_get_boxed (value));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -648,11 +567,6 @@ seahorse_gkr_item_finalize (GObject *gobject)
 	self->pv->item_attrs = NULL;
 	g_assert (self->pv->req_attrs == NULL);
 
-	gnome_keyring_acl_free (self->pv->item_acl);
-	self->pv->item_acl = NULL;
-	self->pv->got_acl = FALSE;
-	g_assert (self->pv->req_acl == NULL);
-
 	g_free (self->pv->item_secret);
 	self->pv->item_secret = NULL;
 	g_assert (self->pv->req_secret == NULL);
@@ -664,21 +578,15 @@ static void
 seahorse_gkr_item_class_init (SeahorseGkrItemClass *klass)
 {
 	GObjectClass *gobject_class;
-	SeahorseObjectClass *seahorse_class;
-    
+
 	seahorse_gkr_item_parent_class = g_type_class_peek_parent (klass);
 	gobject_class = G_OBJECT_CLASS (klass);
 	
-	gobject_class->constructor = seahorse_gkr_item_constructor;
+	gobject_class->constructed = seahorse_gkr_item_constructed;
 	gobject_class->finalize = seahorse_gkr_item_finalize;
 	gobject_class->set_property = seahorse_gkr_item_set_property;
 	gobject_class->get_property = seahorse_gkr_item_get_property;
-	
-	seahorse_class = SEAHORSE_OBJECT_CLASS (klass);
-	seahorse_class->realize = seahorse_gkr_item_realize;
-	seahorse_class->refresh = seahorse_gkr_item_refresh;
-	seahorse_class->delete = seahorse_gkr_item_delete;
-	
+
 	g_type_class_add_private (klass, sizeof (SeahorseGkrItemPrivate));
     
 	g_object_class_install_property (gobject_class, PROP_KEYRING_NAME,
@@ -697,10 +605,6 @@ seahorse_gkr_item_class_init (SeahorseGkrItemClass *klass)
                 g_param_spec_boxed ("item-attributes", "Item Attributes", "GNOME Keyring Item Attributes",
                                     boxed_attributes_type (), G_PARAM_READWRITE));
 
-	g_object_class_install_property (gobject_class, PROP_ITEM_ACL,
-                g_param_spec_boxed ("item-acl", "Item ACL", "GNOME Keyring Item ACL",
-                                    boxed_acl_type (),  G_PARAM_READWRITE));
-
 	g_object_class_install_property (gobject_class, PROP_USE,
 	        g_param_spec_uint ("use", "Use", "Item is used for", 
 	                           0, G_MAXUINT, 0, G_PARAM_READABLE));
@@ -747,7 +651,8 @@ void
 seahorse_gkr_item_set_info (SeahorseGkrItem *self, GnomeKeyringItemInfo* info)
 {
 	GObject *obj;
-	
+	gchar *secret;
+
 	g_return_if_fail (SEAHORSE_IS_GKR_ITEM (self));
 	
 	if (self->pv->item_info)
@@ -759,16 +664,18 @@ seahorse_gkr_item_set_info (SeahorseGkrItem *self, GnomeKeyringItemInfo* info)
 	
 	obj = G_OBJECT (self);
 	g_object_freeze_notify (obj);
-	seahorse_gkr_item_realize (SEAHORSE_OBJECT (self));
+	seahorse_gkr_item_realize (self);
 	g_object_notify (obj, "item-info");
 	g_object_notify (obj, "use");
 	
 	/* Get the secret out of the item info, if not already loaded */
-	if (!self->pv->item_secret && self->pv->item_info && !self->pv->req_secret) {
-		WITH_SECURE_MEM (self->pv->item_secret = gnome_keyring_item_info_get_secret (self->pv->item_info));
+	WITH_SECURE_MEM (secret = gnome_keyring_item_info_get_secret (self->pv->item_info));
+	if (secret != NULL) {
+		gnome_keyring_free_password (self->pv->item_secret);
+		self->pv->item_secret = secret;
 		g_object_notify (obj, "has-secret");
 	}
-		
+
 	g_object_thaw_notify (obj);
 }
 
@@ -811,7 +718,7 @@ seahorse_gkr_item_set_attributes (SeahorseGkrItem *self, GnomeKeyringAttributeLi
 	
 	obj = G_OBJECT (self);
 	g_object_freeze_notify (obj);
-	seahorse_gkr_item_realize (SEAHORSE_OBJECT (self));
+	seahorse_gkr_item_realize (self);
 	g_object_notify (obj, "item-attributes");
 	g_object_notify (obj, "use");
 	g_object_thaw_notify (obj);
@@ -844,35 +751,6 @@ seahorse_gkr_find_string_attribute (GnomeKeyringAttributeList *attrs, const gcha
 	return NULL;	
 }
 
-GList*
-seahorse_gkr_item_get_acl (SeahorseGkrItem *self)
-{
-	g_return_val_if_fail (SEAHORSE_IS_GKR_ITEM (self), NULL);
-	require_item_acl (self);
-	return self->pv->item_acl;
-}
-
-void
-seahorse_gkr_item_set_acl (SeahorseGkrItem *self, GList* acl)
-{
-	GObject *obj;
-	
-	g_return_if_fail (SEAHORSE_IS_GKR_ITEM (self));
-	
-	if (self->pv->item_acl)
-		gnome_keyring_acl_free (self->pv->item_acl);
-	if (acl)
-		self->pv->item_acl = gnome_keyring_acl_copy (acl);
-	else
-		self->pv->item_acl = NULL;
-	
-	obj = G_OBJECT (self);
-	g_object_freeze_notify (obj);
-	seahorse_gkr_item_realize (SEAHORSE_OBJECT (self));
-	g_object_notify (obj, "item-acl");
-	g_object_thaw_notify (obj);
-}
-
 GQuark
 seahorse_gkr_item_get_cannonical (const gchar *keyring_name, guint32 item_id)
 {
