@@ -21,10 +21,8 @@
  */
 
 #include "seahorse-prefs.h"
-#include "seahorse-gconf.h"
 #include "seahorse-preferences.h"
 #include "seahorse-widget.h"
-#include "seahorse-check-button-control.h"
 
 /**
  * seahorse_preferences_show:
